@@ -8,14 +8,14 @@
    <phkehl@gmx.net>, http://guv.ethz.ch/~flip/cvsd/,
    http://www.oinkzwurgl.org/software/cvsd/.
 
-   after that Arthur de Jong <arthur@ch.tudelft.nl>
+   after that Arthur de Jong <arthur@arthurdejong.org>
    took up the work and did a complete rewrite,
-   http://ch.tudelft.nl/~arthur/cvsd.
+   http://arthurdejong.org/cvsd/
 
    Copyright (C) 1999 Chris Black.
    Copyright (C) 2000 Philippe Kehl.
-   Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008
-                 Arthur de Jong.
+   Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009,
+                 2010 Arthur de Jong.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -124,7 +124,7 @@ static void display_version(FILE *fp)
 {
   fprintf(fp,"%s\n",PACKAGE_STRING);
   fprintf(fp,"Written by Chris Black, Philippe Kehl and Arthur de Jong.\n\n");
-  fprintf(fp,"Copyright (C) 1999-2008 Chris Black, Philippe Kehl and Arthur de Jong.\n"
+  fprintf(fp,"Copyright (C) 1999-2010 Chris Black, Philippe Kehl and Arthur de Jong.\n"
              "This is free software; see the source for copying conditions.  There is NO\n"
              "warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n");
 }
@@ -287,13 +287,13 @@ static void reap_deadchildren(void)
 }
 
 /* signal handler for dying children */
-static RETSIGTYPE sigchld_handler(int signum)
+static void sigchld_handler(int signum)
 {
 }
 
 
 /* signal handler for closing down */
-static RETSIGTYPE sigexit_handler(int signum)
+static void sigexit_handler(int signum)
 {
   cvsd_exitsignal=signum;
 }
@@ -669,7 +669,7 @@ static void write_pidfile(const char *filename)
 
 
 /* try to install signal handler and check result */
-static void install_sighandler(int signum,RETSIGTYPE (*handler) (int))
+static void install_sighandler(int signum,void (*handler) (int))
 {
   struct sigaction act;
   memset(&act,0,sizeof(struct sigaction));
